raffle.generator module
=======================

.. .. automodule:: raffle.Generator
..    :members:
..    :undoc-members:
..    :show-inheritance:


.. autoclass:: raffle.Generator
   :members:
   :undoc-members:
   :show-inheritance: